( cd usr/bin ; rm -rf gunzip )
( cd usr/bin ; ln -sf /bin/gzip gunzip )
( cd usr/bin ; rm -rf zcat )
( cd usr/bin ; ln -sf /bin/gzip zcat )
( cd usr/bin ; rm -rf zgrep )
( cd usr/bin ; ln -sf /cdrom/usr/bin/zgrep zgrep )
( cd usr/bin ; rm -rf zforce )
( cd usr/bin ; ln -sf /cdrom/usr/bin/zforce zforce )
( cd usr/bin ; rm -rf znew )
( cd usr/bin ; ln -sf /cdrom/usr/bin/znew znew )
( cd usr/bin ; rm -rf zdiff )
( cd usr/bin ; ln -sf /cdrom/usr/bin/zdiff zdiff )
( cd usr/bin ; rm -rf gzexe )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gzexe gzexe )
( cd usr ; rm -rf man )
( cd usr ; ln -sf /cdrom/usr/man man )
( cd bin ; rm -rf gunzip )
( cd bin ; ln -sf gzip gunzip )
( cd bin ; rm -rf zcat )
( cd bin ; ln -sf gzip zcat )
